@@ -1,6 +1,6 @@
 from columnar import columnar
 
-from slai.clients.project import ProjectClient
+from slai.clients.project import get_project_client
 
 from slai_cli import log
 from slai_cli.decorators import requires_slai_project
@@ -8,7 +8,7 @@ from slai_cli.decorators import requires_slai_project
 
 @requires_slai_project
 def list_models():
-    project_client = ProjectClient()
+    project_client = get_project_client(project_name=None)
     models = project_client.list_models()
 
     headers = ["id", "name", "created", "updated", "version"]
