@@ -8,7 +8,7 @@ from slai_cli.modules.drive_client import DriveClient
 from slai_cli.modules.stoppable_thread import StoppableThread
 from slai_cli.constants import MODEL_WATCH_INTERVAL_S
 from slai_cli.model.save import save_model
-from slai_cli.create.local_config_helper import LocalConfigHelper
+from slai_cli.init.local_config_helper import LocalConfigHelper
 
 CYCLES_PER_DOWNLOAD = 5
 
